@@ -44,9 +44,9 @@ gboolean readcd_makeimage_callback(GIOChannel *Astd, GIOCondition Acond, gpointe
 {
   GIOStatus Lstatus;
   Tgrave *Lg = (Tgrave *)Adata;
-  GtkLabel *Ltitle = GTK_LABEL(sc_grave_get_widget(Lg, "gravetitle"));
-  GtkProgressBar *Lprogressbar = GTK_PROGRESS_BAR(sc_grave_get_widget(Lg, "pb_total"));
-  GtkProgressBar *Lprogressbar2 = GTK_PROGRESS_BAR(sc_grave_get_widget(Lg, "pb_step"));
+  GtkLabel *Ltitle = GTK_LABEL(sc_grave_get_data(Lg, "gravetitle"));
+  GtkProgressBar *Lprogressbar = GTK_PROGRESS_BAR(sc_grave_get_data(Lg, "pb_total"));
+  GtkProgressBar *Lprogressbar2 = GTK_PROGRESS_BAR(sc_grave_get_data(Lg, "pb_step"));
   gint *Lcont = (gint *) sc_grave_get_data(Lg, "cont"); /* on traite encore des donnees ? */
   GError **Lerreur = (GError **) sc_grave_get_data(Lg, "gerror"); /* pointeur erreur */
   gdouble *Lreadtodo = (gdouble *) sc_grave_get_data(Lg, "readtodo"); /* nombre de secteur a traiter */
@@ -153,16 +153,13 @@ gboolean make_image(Tgrave *Ag, GError **Aerror)
   gint g_in, g_out, g_err, Lnbrarg;
   gboolean Lstatus = FALSE;
   gchar *Lbufvitesse;
-  gchar *Lbuflect;
-  GtkWidget *Llecteur = sc_grave_get_widget(Ag, "srccopycombo");
+  Tdriveinfo *Ldevice = get_drive_info(Ag, "srccopycombo");
 
   gtk_label_set_text(Ltitle, _("Duplication will start shortly..."));
 
   Lbufvitesse = get_combo_value(Lvitesse);
-  Lbuflect = get_combo_value(Llecteur);
   Lcommandline = g_strdup_printf("%s dev=%s f=\"%s\" %s%s -v",
-        conf_get_string("readcd"), Lbuflect, Liso, *Lbufvitesse != '0' ? "speed=" : "", *Lbufvitesse != '0' ? Lbufvitesse : "");
-  g_free(Lbuflect);
+        conf_get_string("readcd"), DRIVE_DEV(Ldevice), Liso, *Lbufvitesse != '0' ? "speed=" : "", *Lbufvitesse != '0' ? Lbufvitesse : "");
   g_free(Lbufvitesse);
 
   _DEB("execution [%s]\n", Lcommandline);
@@ -208,6 +205,7 @@ gboolean make_image(Tgrave *Ag, GError **Aerror)
   g_io_channel_unref(Lcomerr);  
   g_io_channel_shutdown(Lcom, FALSE, NULL);
   g_io_channel_unref(Lcom);
+
   g_spawn_close_pid(*Lpid);
   *Lpid = 0;
 
