@@ -1,5 +1,5 @@
 /* sox.c
- * Copyright (C) 2004, 2005 Sylvain Cresto <sylvain.cresto@tiscali.fr>
+ * Copyright (C) 2004, 2005 Sylvain Cresto <scresto@gmail.com>
  *
  * This file is part of graveman!
  *
@@ -24,8 +24,41 @@
 
 #include "graveman.h"
 
+#define SOX_ERROR "sox:"
+#define SOX_FILE_NOT_FOUND "No such file or directory"
+#define SOX_FAILED_READING "Failed reading"
+
+#define SOX_MP3 "mp3"
+#define SOX_OGG "vorbis"
+
 /* communication avec sox */
 
+/* verification que sox ai bien le support ogg et mp3 */
+gboolean check_sox()
+{
+  gchar *Lsox = conf_get_string("sox");
+  gchar *Lcommandline, *Lerr = NULL;
+  gboolean Lstatus;
+  gint Lexit = 0;
+
+  GsupportMp3 = FALSE;
+  GsupportOgg = FALSE;
+
+  if (!Lsox || !*Lsox) return FALSE;
+
+  Lcommandline = g_strdup_printf("%s -help", conf_get_string("sox"));
+  Lstatus = g_spawn_command_line_sync(Lcommandline, NULL, &Lerr, &Lexit, NULL);
+  g_free(Lcommandline);
+
+  GsupportMp3 = (Lstatus == TRUE && Lerr && ((strstr(Lerr, SOX_MP3))));
+  GsupportOgg = (Lstatus == TRUE && Lerr && ((strstr(Lerr, SOX_OGG))));
+  
+  g_free(Lerr);
+
+  return Lstatus;
+}
+
+
 /* transformation fichier son vers piste audio */
 
 /* pour le moment on ne fais pas grand chose dans le callback ...
@@ -33,40 +66,54 @@
 gboolean sox_callback(GIOChannel *Astd, GIOCondition Acond, gpointer Adata)
 {
   GIOStatus Lstatus;
-  gboolean *Lcont = (gboolean *) Adata;
+  Tgrave *Lg = (Tgrave *)Adata;
   gchar *Lbuffer = NULL;  
+  gchar *s;
+  gint *Lcont = (gint *) sc_grave_get_data(Lg, "cont"); /* on traite encore des donnees ? */
+  GError **Lerreur = (GError **) sc_grave_get_data(Lg, "gerror"); /* pointeur erreur */
+
 
   /* fin du callback lorsque l'on recoi un signal comme quoi le pipe est ferme */
   if (Acond == G_IO_HUP || Acond == G_IO_ERR) {
-    *Lcont = FALSE;
+    *Lcont = 1;
     return FALSE;
   }
 
   Lstatus = g_io_channel_read_line(Astd, &Lbuffer, NULL, NULL, NULL);
+  _DEB("%s\n", Lbuffer);  
+  if (Lbuffer) {
+    if (( (strstr(Lbuffer, SOX_FILE_NOT_FOUND)) || (strstr(Lbuffer, SOX_FAILED_READING)) ) &&
+          ((s=strstr(Lbuffer, SOX_ERROR)))) {
+      g_set_error(Lerreur, GRAVEMAN_ERROR, _ERR_SOX, s+strlen(SOX_ERROR));
+      g_free(Lbuffer);
+      return FALSE;
+    }
+  }
 
   g_free(Lbuffer);
 
   return TRUE;
 }
 
-gboolean SoundToCdr(GHashTable *Ahash, gchar *AFichier, gchar *AVers, GError **Aerror)
+gboolean SoundToCdr(Tgrave *Ag, gchar *AFichier, gchar *AVers, GError **Aerror)
 {
   gchar *Lcommandline;
   gchar **Lcmd;
-  gint *Lpid = (gint *) g_hash_table_lookup(Ahash, "pid");
-  gboolean *Labort = (gboolean *)g_hash_table_lookup(Ahash, "gabort");
+  gint *Lpid = (gint *) sc_grave_get_data(Ag, "pid");
+  gboolean *Labort = (gboolean *)sc_grave_get_data(Ag, "gabort");
+  gint *Lcont = (gint *) sc_grave_get_data(Ag, "cont");
   gint g_out, g_err, Lnbrarg;
   gchar *Lfic;
   gchar *Lvers;
   GIOChannel *Lcom, *Lcomerr;
-  gboolean Lcont = TRUE;
   GIOStatus Lstatus;
   gboolean Lbolstatus;
   guint Lcomevent, Lcomerrevent;
 
-  Lfic = sc_get_filename(AFichier);
-  Lvers = sc_get_filename(AVers);
-  Lcommandline = g_strdup_printf("%s -V %s \"%s\" \"%s\"", conf_get_string("sox"), conf_get_string("soxpara"), Lfic, Lvers);
+  Lfic = sc_strescape(AFichier);
+  Lvers = sc_strescape(AVers);
+  Lcommandline = g_strdup_printf("%s %s \"%s\" \"%s\"", conf_get_string("sox"), conf_get_string("soxpara"), Lfic, Lvers);
+  g_free(Lvers); g_free(Lfic);
   _DEB("execution [%s]\n", Lcommandline);
 
   Lstatus = g_shell_parse_argv(Lcommandline, &Lnbrarg, &Lcmd, Aerror);
@@ -76,7 +123,7 @@ gboolean SoundToCdr(GHashTable *Ahash, gchar *AFichier, gchar *AVers, GError **A
   }
 
   Lbolstatus = g_spawn_async_with_pipes(NULL, Lcmd, NULL, /* env argument */
-      (GSpawnFlags ) (0),
+      (GSpawnFlags ) (G_SPAWN_DO_NOT_REAP_CHILD),
       NULL, NULL, Lpid, NULL, &g_out, &g_err, Aerror);
   g_strfreev(Lcmd);
 
@@ -84,23 +131,25 @@ gboolean SoundToCdr(GHashTable *Ahash, gchar *AFichier, gchar *AVers, GError **A
     g_warning("ERROR EXECUTION !\n");
     return FALSE;
   }
-
   Lcom = g_io_channel_unix_new( g_out );
   g_io_channel_set_encoding (Lcom, NULL, NULL);
   g_io_channel_set_flags( Lcom, G_IO_FLAG_NONBLOCK, NULL );
   Lcomevent = g_io_add_watch (Lcom, (G_IO_IN | G_IO_HUP | G_IO_ERR | G_IO_PRI),
 					     sox_callback,
-					     &Lcont);
+					     Ag);
   
   Lcomerr = g_io_channel_unix_new( g_err );
   g_io_channel_set_encoding (Lcomerr, NULL, NULL);
   g_io_channel_set_flags( Lcomerr, G_IO_FLAG_NONBLOCK, NULL );
   Lcomerrevent = g_io_add_watch (Lcomerr, (G_IO_IN | G_IO_HUP | G_IO_ERR | G_IO_PRI),
 					     sox_callback,
-					     &Lcont);  
-  while (Lcont) {
+					     Ag);  
+
+  while (*Lcont > 1 && *Labort == FALSE) {
     gtk_main_iteration(); 
   }
+  exit_prog(*Lpid, *Labort, Aerror, NULL);
+
   g_source_remove(Lcomerrevent);
   g_source_remove(Lcomevent);
       
@@ -112,7 +161,7 @@ gboolean SoundToCdr(GHashTable *Ahash, gchar *AFichier, gchar *AVers, GError **A
   *Lpid = 0;
 
   /* l'utilisateur a annule l'operation */
-  if (*Labort==TRUE) return FALSE;
+  if (*Labort==TRUE || *Aerror) return FALSE;
 
   return TRUE;
 }
