@@ -223,6 +223,19 @@ GtkWidget *sc_grave_get_widget(Tgrave *Agrave, gchar *Aname)
   return glade_xml_get_widget(Agrave->xml, Aname);
 }
 
+gpointer sc_grave_get_widgetordata(Tgrave *Agrave, gchar *Aname)
+{
+  gpointer Ldata = NULL;
+  if (Agrave == NULL || Agrave->xml == NULL) return NULL;
+
+  if ((Ldata = glade_xml_get_widget(Agrave->xml, Aname))) return Ldata;
+
+  if ((Ldata = g_hash_table_lookup(Agrave->data, Aname))) return Ldata;
+
+  return NULL;
+  
+}
+
 GtkWidget *sc_grave_get_widgetv(Tgrave *Agrave, gchar *Aformat, ...)
 {
   va_list Largs;
